Name:          ds9
Version:       8.6
Summary:       Astronomical Data Visualization Application
Release:       %mkrel 2
License:       GPLv3+
Group:         Sciences/Astronomy

URL:           https://sites.google.com/cfa.harvard.edu/saoimageds9/home
Source:        https://hea-www.harvard.edu/RD/ds9/download/source/ds9.%{version}.tar.gz
Source1:       ds9.desktop
Source2:       ds9.png

#(eatdirt): test
#ExcludeArch:   #{arm} aarch64

#these patches remove the static deps to lib we already have, when
#possible (mind tclxml which is not the genuine version).


#in configure.in
Patch0:        ds9-8.2-configure.patch

#in make.include
Patch2:        ds9-8.6-include.patch
#in makefile.in
Patch3:        ds9-8.6-makefile.patch
#fix missing include for tkhtml
Patch4:        ds9-8.1-tkhtml.patch
#linking to dynamic libs
Patch7:        ds9-8.6-ds9makefile.patch
Patch8:        ds9-8.6-ds9configure.patch
Patch9:        ds9-8.6a-ds9init.patch
Patch10:       ds9-8.6a-ds9tcl.patch

#strict null pointer value
Patch12:       ds9-7.6-tkmpeg-strict.patch
#fix compilation failure of gcat
Patch13:       ds9-8.2.1-gcat.patch
#fix missing include path for tksao
Patch14:       ds9-8.2.1-tksao-include.patch

BuildRequires: zip
BuildRequires: unzip
BuildRequires: perl
BuildRequires: gcc-gfortran
BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(tcl)
BuildRequires: pkgconfig(tk)
BuildRequires: tcl-tcllib
# package modified locally
#BuildRequires: tcl-tclxml-devel
BuildRequires: tkimg-devel
BuildRequires: tkblt-devel
BuildRequires: tcltls-devel
BuildRequires: pkgconfig(xpa)
BuildRequires: pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(libxslt)
BuildRequires: jbigkit-devel
BuildRequires: pkgconfig(libzip)
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(xt)
BuildRequires: pkgconfig(openssl)

Requires:      tcl
Requires:      tk
Requires:      tcl-tcllib
Requires:      tcl-xmlrpc
#Requires:      tcl-tclxml
Requires:      tkblt
Requires:      tcltls

%description
SAOImage DS9 is an astronomical imaging and data visualization
application.  DS9 supports FITS images and binary tables, multiple
frame buffers, region manipulation, and many scale algorithms and
colormaps. It provides interfaces for easy communication with external
analysis tasks and is highly configurable and extensible.

%prep

#As far as the doc says, autosetup and autopatch do not support
#back-up, this pisses me off when debugging, and ds9 needs debugging
#at each release bump.
#autosetup -p1 -n SAOImageDS9

%setup -q -n SAOImageDS9
%patch -P 0 -p1 -b .orig
%patch -P 2 -p1 -b .orig
%patch -P 3 -p1 -b .orig
%patch -P 4 -p1 -b .orig

%patch -P 7 -p1 -b .orig
%patch -P 8 -p1 -b .orig
%patch -P 9 -p1 -b .orig
%patch -P 10 -p1 -b .orig

%patch -P 12 -p1 -b .orig
%patch -P 13 -p1 -b .orig
%patch -P 14 -p1 -b .orig


#clean (some) of the static junk
%__rm -r -f tcl8.6
%__rm -r -f tcllib
#__rm -r -f tclxml
%__rm -r -f tk8.6
%__rm -r -f tkimg
%__rm -r -f tkblt
%__rm -r -f xpa
%__rm -r -f tls
%__rm -r -f openssl
%__rm -r -f tclzipfs




%build
autoreconf -fi ./unix
autoreconf -fi ./ds9/unix
export CONFIGURE_TOP=./unix
%configure
%make_build

%install
%__mkdir_p %{buildroot}%{_bindir}
cp bin/ds9 %{buildroot}%{_bindir}
%__mkdir_p %{buildroot}%{_datadir}/pixmaps
cp -a %{SOURCE2} %{buildroot}%{_datadir}/pixmaps
%__mkdir_p %{buildroot}%{_datadir}/applications
cp -a %{SOURCE1} %{buildroot}%{_datadir}/applications
#####__mkdir_p %%{buildroot}/etc/prelink.conf.d
%__mkdir_p %{buildroot}%{_datadir}/ds9
cp -a share/ds9 %{buildroot}%{_datadir}

%files
%doc LICENSE
%{_bindir}/ds9
%{_datadir}/applications/ds9.desktop
%{_datadir}/pixmaps/ds9.png
%{_datadir}/ds9


%changelog
* Wed Nov 20 2024 eatdirt <eatdirt> 8.6-2.mga10
+ Revision: 2117833
- Fix tk init search paths for new tcl/tk

* Wed Oct 30 2024 daviddavid <daviddavid> 8.6-1.mga10
+ Revision: 2111789
- new version: 8.6
- xmlrpc-c was replaced upstream by bundled tclxmlrpc

* Wed Oct 30 2024 daviddavid <daviddavid> 8.4.1-2.mga10
+ Revision: 2111783
- backport upstream patch to fix tclxml build issue

* Wed Jan 18 2023 eatdirt <eatdirt> 8.4.1-1.mga9
+ Revision: 1934366
- Upgrade to version 8.4.1

* Fri Aug 26 2022 eatdirt <eatdirt> 8.3-1.mga9
+ Revision: 1880913
- Upgrade to version 8.3
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 8.2.1-2.mga9
+ Revision: 1747632
- rebuild for openssl 3.0.0

* Tue Aug 24 2021 eatdirt <eatdirt> 8.2.1-1.mga9
+ Revision: 1742528
- Fix missing symbols
- Fix compilation against new tk and tcltls
- Keep internal version of tclxml (modified)
- Upgrade to version 8.2.1
+ daviddavid <daviddavid>
- rebuild for new tcltls 1.7.22

* Thu Dec 24 2020 eatdirt <eatdirt> 8.2-2.mga8
+ Revision: 1663435
- Try fixing tktable errors on arms

* Wed Dec 23 2020 eatdirt <eatdirt> 8.2-1.mga8
+ Revision: 1663152
- Upgrade to version 8.2

* Thu Jun 11 2020 joequant <joequant> 8.1-2.mga8
+ Revision: 1592521
- bump build
- add patch for tcltls
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Thu Mar 19 2020 eatdirt <eatdirt> 8.1-1.mga8
+ Revision: 1558006
- Upgrade to version 8.1

* Tue Feb 18 2020 umeabot <umeabot> 8.0-6.mga8
+ Revision: 1538556
- Mageia 8 Mass Rebuild

* Thu Nov 21 2019 zezinho <zezinho> 8.0-5.mga8
+ Revision: 1462031
- rebuild for new tcltls 1.7.20

* Wed Oct 16 2019 daviddavid <daviddavid> 8.0-4.mga8
+ Revision: 1454168
- rebuild for new tcltls 1.7.19

* Sat Jul 13 2019 daviddavid <daviddavid> 8.0-3.mga8
+ Revision: 1420855
- rebuild for new tcltls 1.7.18

* Mon Apr 15 2019 daviddavid <daviddavid> 8.0-2.mga7
+ Revision: 1390644
- update tcltls_version in ds9configure patch
- rebuild for new tcltls 1.7.17

* Wed Dec 19 2018 eatdirt <eatdirt> 8.0-1.mga7
+ Revision: 1343011
- Upgrade to version 8.0

* Sun Sep 23 2018 umeabot <umeabot> 7.6-3.mga7
+ Revision: 1297515
- Mageia 7 Mass Rebuild

* Wed Jun 06 2018 eatdirt <eatdirt> 7.6-2.mga7
+ Revision: 1234956
- Fix missing xml module in ds9.tcl

* Wed Jun 06 2018 eatdirt <eatdirt> 7.6-1.mga7
+ Revision: 1234948
- Upgrade to version 7.6

* Tue Oct 10 2017 zezinho <zezinho> 7.5-2.mga7
+ Revision: 1170754
- new version
- use an external tkblt

* Sat May 20 2017 eatdirt <eatdirt> 7.5-2.mga6
+ Revision: 1103448
- Unobsoleting ds9

* Tue Feb 14 2017 eatdirt <eatdirt> 7.5-1.mga6
+ Revision: 1086135
- Upgrade to version 7.5

* Fri Apr 01 2016 eatdirt <eatdirt> 7.4.1-3.mga6
+ Revision: 997324
- Fix missing requires

* Thu Mar 31 2016 eatdirt <eatdirt> 7.4.1-2.mga6
+ Revision: 997168
- Fix linking against xpa and xml, allow stripping
- Upgraded to version 7.4.1, added support to tcl8.6
- Restoring ds9 from obsolete
+ joequant <joequant>
- remove since it doesn't build
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ daviddavid <daviddavid>
- rebuild for new tcl/tk 8.6.4

* Fri Sep 18 2015 tv <tv> 7.2-10.mga6
+ Revision: 880367
- fix & re-enable debuginfo
- fix & re-enable debuginfo

* Wed Sep 09 2015 neoclust <neoclust> 7.2-9.mga6
+ Revision: 874932
- Fix build with new rpm ( empty debuginfo)

* Tue May 05 2015 eatdirt <eatdirt> 7.2-8.mga5
+ Revision: 821275
- Bumping release tag

* Mon Feb 23 2015 joequant <joequant> 7.2-7.mga5
+ Revision: 816753
- add tk - fix 15345

* Wed Oct 15 2014 umeabot <umeabot> 7.2-6.mga5
+ Revision: 743232
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 7.2-5.mga5
+ Revision: 678869
- Mageia 5 Mass Rebuild

* Thu Jun 19 2014 eatdirt <eatdirt> 7.2-4.mga5
+ Revision: 638084
- Rebuilt for tcl 8.5.15

* Sat Oct 19 2013 umeabot <umeabot> 7.2-3.mga4
+ Revision: 531960
- Mageia 4 Mass Rebuild

* Tue Aug 13 2013 joequant <joequant> 7.2-2.mga4
+ Revision: 466150
- update syslib files to fix #10991

* Mon Jul 29 2013 joequant <joequant> 7.2-1.mga4
+ Revision: 460406
- upgrade to 7.2

* Fri Jun 07 2013 joequant <joequant> 7.1-1.mga4
+ Revision: 440254
- add xt-devel build requires
- fix category and improve macros
- change source to package requires
- imported package ds9

